handle_init

Function handle_init 

pub async fn handle_init(
    __arg0: State<AppState>,
    headers: HeaderMap,
    __arg2: Query<InitQuery>,
) -> Response
POST /api/config/init?section=model_providers — instantiate None nested sections with defaults, and only those: dynamic-map aliases are created through POST /api/config/map-key. When every requested section is already configured, returns {initialized: []}.