Struct AliasSourceQuery
pub struct AliasSourceQuery {
pub source: AliasSource,
}Fields
source: AliasSourceTrait Implementations
Sourceimpl Debug for AliasSourceQuery
impl Debug for AliasSourceQuery
Sourceimpl<'de> Deserialize<'de> for AliasSourceQuery
impl<'de> Deserialize<'de> for AliasSourceQuery
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AliasSourceQuery
impl JsonSchema for AliasSourceQuery
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AliasSourceQuery
impl RefUnwindSafe for AliasSourceQuery
impl Send for AliasSourceQuery
impl Sync for AliasSourceQuery
impl Unpin for AliasSourceQuery
impl UnsafeUnpin for AliasSourceQuery
impl UnwindSafe for AliasSourceQuery