Struct ChannelBindBody
pub struct ChannelBindBody {
pub channel_type: String,
pub alias: String,
pub identity: String,
}Expand description
POST /api/channels/bind request body. The GUI/HTTP equivalent of
zeroclaw channel bind-<type> <identity> --alias <alias>: authorize an
operator-named identity on one channel alias without the in-chat
/bind <code> round trip.
Fields
channel_type: Stringalias: Stringidentity: StringTrait Implementations
Sourceimpl Debug for ChannelBindBody
impl Debug for ChannelBindBody
Sourceimpl<'de> Deserialize<'de> for ChannelBindBody
impl<'de> Deserialize<'de> for ChannelBindBody
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ChannelBindBody
impl JsonSchema for ChannelBindBody
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ChannelBindBody
impl RefUnwindSafe for ChannelBindBody
impl Send for ChannelBindBody
impl Sync for ChannelBindBody
impl Unpin for ChannelBindBody
impl UnsafeUnpin for ChannelBindBody
impl UnwindSafe for ChannelBindBody