Struct PatchOp
pub struct PatchOp {
pub op: String,
pub path: String,
pub value: Option<Value>,
pub comment: Option<String>,
}Expand description
One JSON Patch operation. Supports add, remove, replace, test, and
ZeroClaw’s comment extension. Every operation requires path; add,
replace, and test require value, while comment requires comment.
Fields
op: Stringpath: Stringvalue: Option<Value>comment: Option<String>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for PatchOp
impl<'de> Deserialize<'de> for PatchOp
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for PatchOp
impl JsonSchema for PatchOp
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for PatchOp
impl RefUnwindSafe for PatchOp
impl Send for PatchOp
impl Sync for PatchOp
impl Unpin for PatchOp
impl UnsafeUnpin for PatchOp
impl UnwindSafe for PatchOp