Struct VersionErrorResponse
pub struct VersionErrorResponse {
pub error: String,
}Expand description
Error envelope for the /api/version/* endpoints (4xx).
Fields
error: StringTrait Implementations
Sourceimpl Debug for VersionErrorResponse
impl Debug for VersionErrorResponse
Sourceimpl JsonSchema for VersionErrorResponse
impl JsonSchema for VersionErrorResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for VersionErrorResponse
impl RefUnwindSafe for VersionErrorResponse
impl Send for VersionErrorResponse
impl Sync for VersionErrorResponse
impl Unpin for VersionErrorResponse
impl UnsafeUnpin for VersionErrorResponse
impl UnwindSafe for VersionErrorResponse